@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from unittest import mock
 from unittest.mock import patch
 
 import py
@@ -7,6 +8,8 @@ import pytest
 from click.testing import CliRunner
 
 from todoman.cli import cli
+from todoman.configuration import CONFIG_SPEC
+from todoman.configuration import ConfigEntry
 from todoman.configuration import ConfigurationError
 from todoman.configuration import load_config
 
@@ -84,11 +87,28 @@ def test_invalid_color_arg(config: py.path.local, runner: CliRunner) -> None:
     assert "Usage:" in result.output
 
 
-def test_missing_path(config: py.path.local, runner: CliRunner) -> None:
+def test_missing_path(
+    config: py.path.local,
+    runner: CliRunner,
+    tmpdir: py.path.local,
+) -> None:
     config.write('color = "auto"\n')
-    result = runner.invoke(cli, ["list"])
-    assert result.exception
-    assert "Error: Missing 'path' setting." in result.output
+
+    temp_calendars = tmpdir.mkdir("calendars")
+    temp_calendars.mkdir("my_list")
+
+    patched_path = ConfigEntry(
+        name=CONFIG_SPEC[0].name,
+        type=CONFIG_SPEC[0].type,
+        default=str(temp_calendars),
+        description=CONFIG_SPEC[0].description,
+        validation=CONFIG_SPEC[0].validation,
+    )
+    new_config_spec = [patched_path] + CONFIG_SPEC[1:]
+
+    with mock.patch("todoman.configuration.CONFIG_SPEC", new_config_spec):
+        result = runner.invoke(cli, ["list"])
+    assert not result.exception
 
 
 @pytest.mark.xfail(reason="Not implemented")
@@ -174,8 +194,11 @@ def test_colour_validation_always(config: py.path.local) -> None:
 
 def test_colour_validation_invalid(config: py.path.local) -> None:
     config.write("color = 'on_weekends_only'\n", "a")
-    with patch(
-        "todoman.configuration.find_config",
-        return_value=(str(config)),
-    ), pytest.raises(ConfigurationError):
+    with (
+        patch(
+            "todoman.configuration.find_config",
+            return_value=(str(config)),
+        ),
+        pytest.raises(ConfigurationError),
+    ):
         load_config()
